==> inspect_ai-0.3.77.tar.gz: inspect_ai-0.3.77/src/inspect_ai/tool/_tools/_think.py <==
from .._tool import Tool, tool
from .._tool_call import ToolCall, ToolCallContent, ToolCallView, ToolCallViewer
from .._tool_def import ToolDef


@tool
def think(
    description: str | None = None,
    thought_description: str | None = None,
) -> Tool:
    """Think tool for extra thinking.

    Tool that provides models with the ability to include an additional thinking step as part of getting to its final answer.

    Note that the `think()` tool is not a substitute for reasoning and extended thinking, but rather an an alternate way of letting models express thinking that is better suited to some tool use scenarios. Please see the documentation on using the [think tool](https://inspect.aisi.org.uk/tools-standard.html#sec-think) before using it in your evaluations.

    Args:
        description: Override the default description of the think tool.
        thought_description: Override the default description of the thought parameter.
    """

    async def execute(thought: str) -> str:
        """Use the tool to think about something.

        The will not obtain new information or change the environment, but just append the thought to the log. Use it when complex reasoning or some cache memory is needed."

        Args:
            thought: A thought to think about.
        """
        return ""

    return ToolDef(
        execute,
        name="think",
        description=description,
        parameters=(dict(thought=thought_description) if thought_description else None),
        viewer=think_tool_viewer(),
    ).as_tool()


def think_tool_viewer() -> ToolCallViewer:
    def viewer(tool_call: ToolCall) -> ToolCallView:
        call = ToolCallContent(
            format="markdown", content=tool_call.arguments["thought"]
        )
        return ToolCallView(call=call)

    return viewer

==> inspect_ai-0.3.93.tar.gz: inspect_ai-0.3.93/src/inspect_ai/tool/_tools/_think.py <==
from .._tool import Tool, tool
from .._tool_call import ToolCall, ToolCallContent, ToolCallView, ToolCallViewer
from .._tool_def import ToolDef


@tool
def think(
    description: str | None = None,
    thought_description: str | None = None,
) -> Tool:
    """Think tool for extra thinking.

    Tool that provides models with the ability to include an additional thinking step as part of getting to its final answer.

    Note that the `think()` tool is not a substitute for reasoning and extended thinking, but rather an an alternate way of letting models express thinking that is better suited to some tool use scenarios. Please see the documentation on using the [think tool](https://inspect.aisi.org.uk/tools-standard.html#sec-think) before using it in your evaluations.

    Args:
        description: Override the default description of the think tool.
        thought_description: Override the default description of the thought parameter.
    """

    async def execute(thought: str) -> str:
        """Use the tool to think about something.

        The will not obtain new information or change the environment, but just append the thought to the log. Use it when complex reasoning or some cache memory is needed.

        Args:
            thought: A thought to think about.
        """
        return ""

    return ToolDef(
        execute,
        name="think",
        description=description,
        parameters=(dict(thought=thought_description) if thought_description else None),
        viewer=think_tool_viewer(),
    ).as_tool()


def think_tool_viewer() -> ToolCallViewer:
    def viewer(tool_call: ToolCall) -> ToolCallView:
        call = ToolCallContent(
            format="markdown", content=tool_call.arguments["thought"]
        )
        return ToolCallView(call=call)

    return viewer
